Crate branchdiff

Crate branchdiff 

branchdiff library - exposes types for benchmarking and testing

Re-exports

pub use app::App;
pub use app::ViewMode;
pub use diff::DiffLine;
pub use diff::LineSource;

Modules

app
Application state and logic module for branchdiff
cli
diff
Diff computation module for branchdiff
file_events
VCS lock state management.
file_links
File link detection for app-spec file pairs
gitignore
Gitignore-aware file filtering for the file watcher.
image_diff
Image diff support for displaying image files in the TUI.
input
limits
Resource limit detection and threshold checking for large repos.
message
Unified message types for application events.
patch
Git unified patch format generation.
syntax
ui
update
Message processing and state updates.
vcs