pub fn load_and_cache(bytes: &[u8], format_name: &str) -> Result<CachedImage>Expand description
Load image bytes and create a cached image with optional downscaling
pub fn load_and_cache(bytes: &[u8], format_name: &str) -> Result<CachedImage>Load image bytes and create a cached image with optional downscaling