parse_inotify_value

Function parse_inotify_value 

pub fn parse_inotify_value(s: &str) -> Option<usize>
Parse an inotify sysctl value from its string representation. Returns None if the string is empty or not a valid number.