Module selection

Module selection 

Constants

SELECTION_BG_COLOR

Functions

apply_selection_to_span
Apply selection highlighting to a span, splitting it if partially selected
get_line_selection_range
Get the selection range for a specific line (start_col, end_col) Returns None if the line is not selected