pub struct DiffLine {
pub source: LineSource,
pub content: String,
pub prefix: char,
pub line_number: Option<usize>,
pub file_path: Option<String>,
pub inline_spans: Vec<InlineSpan>,
pub old_content: Option<String>,
pub change_source: Option<LineSource>,
}Fields
source: LineSourcecontent: Stringprefix: charline_number: Option<usize>file_path: Option<String>inline_spans: Vec<InlineSpan>old_content: Option<String>change_source: Option<LineSource>Implementations
Sourceimpl DiffLine
impl DiffLine
Sourcepub fn file_header(path: &str) -> Self
pub fn file_header(path: &str) -> Self
Create a file header line for a new or modified file.
Sourcepub fn deleted_file_header(path: &str) -> Self
pub fn deleted_file_header(path: &str) -> Self
Create a file header line for a deleted file.
Sourcepub fn renamed_file_header(old_path: &str, new_path: &str) -> Self
pub fn renamed_file_header(old_path: &str, new_path: &str) -> Self
Create a file header line for a renamed file.
Sourcepub fn image_marker(path: &str) -> Self
pub fn image_marker(path: &str) -> Self
Create an image marker line (UI layer will render actual image).
Sourceimpl DiffLine
impl DiffLine
pub fn new( source: LineSource, content: String, prefix: char, line_number: Option<usize>, ) -> Self
pub fn with_old_content(self, old: &str) -> Self
pub fn with_change_source(self, change_source: LineSource) -> Self
pub fn is_change(&self) -> bool
Sourcepub fn is_current_commit(&self) -> bool
pub fn is_current_commit(&self) -> bool
True if this line belongs to jj’s current commit (@). Catches both direct current-commit lines and Base lines with inline modifications from @.
pub fn ensure_inline_spans(&mut self)
pub fn with_file_path(self, path: &str) -> Self
Sourcepub fn is_image_marker(&self) -> bool
pub fn is_image_marker(&self) -> bool
Check if this line is an image marker (for UI rendering)