Constants
Functions
- apply_
selection_ to_ span - Apply selection highlighting to a span, splitting it if partially selected
- get_
line_ selection_ range - Get the selection range for a specific line (start_col, end_col) Returns None if the line is not selected